package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysWorkConfig;
import com.ruoyi.system.service.ISysWorkConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 参数配置Controller
 * 
 * @author qy
 * @date 2024-11-25
 */
@RestController
@RequestMapping("/system/workConfig")
public class SysWorkConfigController extends BaseController
{
    @Autowired
    private ISysWorkConfigService sysWorkConfigService;

    /**
     * 查询参数配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:workConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysWorkConfig sysWorkConfig)
    {
        startPage();
        List<SysWorkConfig> list = sysWorkConfigService.selectSysWorkConfigList(sysWorkConfig);
        return getDataTable(list);
    }

    /**
     * 导出参数配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:workConfig:export')")
    @Log(title = "参数配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysWorkConfig sysWorkConfig)
    {
        List<SysWorkConfig> list = sysWorkConfigService.selectSysWorkConfigList(sysWorkConfig);
        ExcelUtil<SysWorkConfig> util = new ExcelUtil<SysWorkConfig>(SysWorkConfig.class);
        util.exportExcel(response, list, "参数配置数据");
    }

    /**
     * 获取参数配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:workConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysWorkConfigService.selectSysWorkConfigById(id));
    }

    /**
     * 新增参数配置
     */
    @PreAuthorize("@ss.hasPermi('system:workConfig:add')")
    @Log(title = "参数配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysWorkConfig sysWorkConfig)
    {
        return toAjax(sysWorkConfigService.insertSysWorkConfig(sysWorkConfig));
    }

    /**
     * 修改参数配置
     */
    @PreAuthorize("@ss.hasPermi('system:workConfig:edit')")
    @Log(title = "参数配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysWorkConfig sysWorkConfig)
    {
        return toAjax(sysWorkConfigService.updateSysWorkConfig(sysWorkConfig));
    }

    /**
     * 删除参数配置
     */
    @PreAuthorize("@ss.hasPermi('system:workConfig:remove')")
    @Log(title = "参数配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysWorkConfigService.deleteSysWorkConfigByIds(ids));
    }
}
